@@ -1,12 +1,9 @@
 #pragma once
+#include <memory>
 #include <stdint.h>
 #include <stddef.h>
 #include <panda/cast.h>
 
-#ifdef CPP11X
-#  include <memory>
-#endif
-
 namespace panda {
 
 static long int void_refcnt = 1;
@@ -240,19 +237,17 @@ inline shared_ptr<T1,true> dynamic_pointer_cast (const shared_ptr<T2,true>& shpt
     return shared_ptr<T1,true>();
 }
 
-#ifdef CPP11X
-    template <typename T1, typename T2>
-    inline std::shared_ptr<T1> static_pointer_cast (const std::shared_ptr<T2>& shptr) {
-        return std::static_pointer_cast<T1>(shptr);
-    }
-    template <typename T1, typename T2>
-    inline std::shared_ptr<T1> const_pointer_cast (const std::shared_ptr<T2>& shptr) {
-        return std::const_pointer_cast<T1>(shptr);
-    }
-    template <typename T1, typename T2>
-    inline std::shared_ptr<T1> dynamic_pointer_cast (const std::shared_ptr<T2>& shptr) {
-        return std::dynamic_pointer_cast<T1>(shptr);
-    }
-#endif
+template <typename T1, typename T2>
+inline std::shared_ptr<T1> static_pointer_cast (const std::shared_ptr<T2>& shptr) {
+    return std::static_pointer_cast<T1>(shptr);
+}
+template <typename T1, typename T2>
+inline std::shared_ptr<T1> const_pointer_cast (const std::shared_ptr<T2>& shptr) {
+    return std::const_pointer_cast<T1>(shptr);
+}
+template <typename T1, typename T2>
+inline std::shared_ptr<T1> dynamic_pointer_cast (const std::shared_ptr<T2>& shptr) {
+    return std::dynamic_pointer_cast<T1>(shptr);
+}
 
 }
