@@ -9,10 +9,8 @@ template <class DOWN, class UP>
 inline DOWN downgrade (const panda::shared_ptr<UP, true>& sp) { return panda::static_pointer_cast<typename DOWN::element_type>(sp); }
 template <class DOWN, class UP>
 inline DOWN downgrade (const panda::shared_ptr<UP, false>& sp) { return panda::static_pointer_cast<typename DOWN::element_type>(sp); }
-#ifdef CPP11X
 template <class DOWN, class UP>
 inline DOWN downgrade (const std::shared_ptr<UP>& sp) { return std::static_pointer_cast<typename DOWN::element_type>(sp); }
-#endif
 
 template <class UP, class DOWN>
 inline UP upgrade (DOWN* var) { return panda::dyn_cast<UP>(var); }
@@ -20,10 +18,8 @@ template <class UP, class DOWN>
 inline UP upgrade (const panda::shared_ptr<DOWN, true>& sp) { return panda::dynamic_pointer_cast<typename UP::element_type>(sp); }
 template <class UP, class DOWN>
 inline UP upgrade (const panda::shared_ptr<DOWN, false>& sp) { return panda::dynamic_pointer_cast<typename UP::element_type>(sp); }
-#ifdef CPP11X
 template <class UP, class DOWN>
 inline UP upgrade (const std::shared_ptr<DOWN>& sp) { return std::dynamic_pointer_cast<typename UP::element_type>(sp); }
-#endif
 
 
 inline SV* out_oref (pTHX_ SV* var, HV* CLASS) {
@@ -48,7 +44,7 @@ inline SV* out_optr (pTHX_ void* var, SV* CLASS) {
 
 template <class T, typename C>
 inline SV* out_optr (pTHX_ const panda::shared_ptr<T, true>& sp, C CLASS) {
-     sp->retain();
+     if (sp) sp->retain();
      return out_optr(aTHX_ sp.get(), CLASS);
 }
 
@@ -57,25 +53,21 @@ inline SV* out_optr (pTHX_ const panda::shared_ptr<T, false>& sp, C CLASS) {
     return out_optr(aTHX_ new panda::shared_ptr<T>(sp), CLASS);
 }
 
-#ifdef CPP11X
 template <class T, typename C>
 inline SV* out_optr (pTHX_ const std::shared_ptr<T>& sp, C CLASS) {
     return out_optr(aTHX_ new std::shared_ptr<T>(sp), CLASS);
 }
-#endif
 
 
 
 template <class T>
 void* out_oext_mgp (T* varptr) { return varptr; }
 template <class T>
-void* out_oext_mgp (const panda::shared_ptr<T, true>& sp) { sp->retain(); return sp.get(); }
+void* out_oext_mgp (const panda::shared_ptr<T, true>& sp) { if (sp) sp->retain(); return sp.get(); }
 template <class T>
 void* out_oext_mgp (const panda::shared_ptr<T, false>& sp) { return new panda::shared_ptr<T>(sp); }
-#ifdef CPP11X
 template <class T>
 void* out_oext_mgp (const std::shared_ptr<T>& sp) { return new std::shared_ptr<T>(sp); }
-#endif
 
 SV* _out_oext (pTHX_ SV* self, void* var, HV* CLASS, payload_marker_t* marker = NULL);
 SV* _out_oext (pTHX_ SV* self, void* var, SV* CLASS, payload_marker_t* marker = NULL);
@@ -118,7 +110,6 @@ inline void* in_optr (pTHX_ SV* arg, panda::shared_ptr<T,false>* sptr) {
     return mgp;
 }
 
-#ifdef CPP11X
 template <class T>
 inline void* in_optr (pTHX_ SV* arg, std::shared_ptr<T>* sptr) {
     void* mgp;
@@ -126,7 +117,6 @@ inline void* in_optr (pTHX_ SV* arg, std::shared_ptr<T>* sptr) {
     *sptr = *(static_cast<std::shared_ptr<T>*>(mgp));
     return mgp;
 }
-#endif
 
 
 
@@ -136,10 +126,8 @@ template <class T>
 inline void in_oext_mgp (panda::shared_ptr<T,true>* sptr, void* mgp) { *sptr = static_cast<T*>(mgp); }
 template <class T>
 inline void in_oext_mgp (panda::shared_ptr<T,false>* sptr, void* mgp) { *sptr = *(static_cast<panda::shared_ptr<T,false>*>(mgp)); }
-#ifdef CPP11X
 template <class T>
 inline void in_oext_mgp (std::shared_ptr<T>* sptr, void* mgp) { *sptr = *(static_cast<std::shared_ptr<T>*>(mgp)); }
-#endif
 
 // set null only for pointers, not for shared pointers as they are already nulls on creation
 template <class T>
@@ -188,12 +176,10 @@ struct AutoDelete<panda::shared_ptr<UP, false>, DOWN> {
     AutoDelete (const panda::shared_ptr<UP, false>& sp, void* mgp) { delete static_cast<panda::shared_ptr<DOWN,false>*>(mgp); }
 };
 
-#ifdef CPP11X
 template <class UP, class DOWN>
 struct AutoDelete<std::shared_ptr<UP>, DOWN> {
     AutoDelete (const std::shared_ptr<UP>& sp, void* mgp) { delete static_cast<std::shared_ptr<DOWN>*>(mgp); }
 };
-#endif
 
 template <class T>
 xs::XSBackref* get_xsbr (T var) { return panda::dyn_cast<xs::XSBackref*>(var); }
@@ -201,10 +187,8 @@ template <class T>
 xs::XSBackref* get_xsbr (panda::shared_ptr<T,true>& var) { return panda::dyn_cast<xs::XSBackref*>(var.get()); }
 template <class T>
 xs::XSBackref* get_xsbr (panda::shared_ptr<T,false>& var) { return panda::dyn_cast<xs::XSBackref*>(var.get()); }
-#ifdef CPP11X
 template <class T>
 xs::XSBackref* get_xsbr (std::shared_ptr<T>& var) { return panda::dyn_cast<xs::XSBackref*>(var.get()); }
-#endif
 
 template <class T>
 T svdup_clone (pTHX_ T obj) { return obj->clone(); }
