@@ -11,11 +11,6 @@ extern "C" {
 }
 #include "ppport.h"
 
-// detect C++11 most feature-capable compiler
-#if __cplusplus >= 201103L
-#  define CPP11X
-#endif
-
 #include <algorithm_perlsafe> // safe c++11 compilation
 #include <panda/cast.h>
 #include <panda/refcnt.h>
