@@ -24,18 +24,14 @@ typedef panda::shared_ptr<MyChild> MyChildSP;
 typedef MyBaseSP  PTRMyBaseSP;
 typedef MyChildSP PTRMyChildSP;
 
-#ifdef CPP11X
 typedef std::shared_ptr<MyBase>  MyBaseSSP;
 typedef std::shared_ptr<MyChild> MyChildSSP;
 typedef MyBaseSSP  PTRMyBaseSSP;
 typedef MyChildSSP PTRMyChildSSP;
-#endif
 
 static MyBaseSP st_mybase_sp;
 
-#ifdef CPP11X
 static MyBaseSSP st_mybase_ssp;
-#endif
 
 typedef MyBase  MyBaseAV;
 typedef MyBase  MyBaseHV;
